# jwt_django
## discontinue
jwt_django discontinue for some reasons <br>

include all the feature merge the webraft libarary https://github.com/MominIqbal-1234/webraft with new update <br>
pypi : https://pypi.org/project/webraft/ <br>
doc : https://webraft.mefiz.com


Check Our Site : https://mefiz.com </br>
Developed by : Momin Iqbal
